# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/radio/radio.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/radio/radio.proto',
  package='stellarstation.api.v1.radio',
  syntax='proto3',
  serialized_options=_b('\n\037com.stellarstation.api.v1.radioB\nRadioProtoP\001Z8github.com/infostellarinc/go-stellarstation/api/v1/radio'),
  serialized_pb=_b('\n\'stellarstation/api/v1/radio/radio.proto\x12\x1bstellarstation.api.v1.radio\"\xcb\x01\n\x18RadioDeviceConfiguration\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12;\n\nmodulation\x18\x02 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x0f\n\x07\x62itrate\x18\x03 \x01(\x04\x12\x44\n\x08protocol\x18\x04 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.CommunicationProtocol\"\x90\x02\n\x15\x43ommunicationProtocol\x12\x31\n\x04\x61x25\x18\x01 \x01(\x0b\x32!.stellarstation.api.v1.radio.AX25H\x00\x12@\n\x05\x63\x63sds\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.radio.CCSDSTransferFrameH\x00\x12;\n\tbitstream\x18\x03 \x01(\x0b\x32&.stellarstation.api.v1.radio.BitstreamH\x00\x12:\n\tasm_golay\x18\x04 \x01(\x0b\x32%.stellarstation.api.v1.radio.ASMGolayH\x00\x42\t\n\x07\x46raming\"\xc4\x03\n\x1e\x43\x43SDSConvolutionalCodingParams\x12m\n\x14polynomial_inversion\x18\x01 \x01(\x0e\x32O.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.PolynomialInversion\x12Z\n\npuncturing\x18\x02 \x01(\x0e\x32\x46.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.Puncturing\"S\n\x13PolynomialInversion\x12\t\n\x05G1_G2\x10\x00\x12\x12\n\x0eG1_G2_INVERTED\x10\x01\x12\x12\n\x0eG2_INVERTED_G1\x10\x02\x12\t\n\x05G2_G1\x10\x03\"\x81\x01\n\nPuncturing\x12\x07\n\x03OFF\x10\x00\x12\x10\n\x0cPUNCTURE_2_3\x10\x01\x12\x10\n\x0cPUNCTURE_3_4\x10\x02\x12\x10\n\x0cPUNCTURE_4_5\x10\x03\x12\x10\n\x0cPUNCTURE_5_6\x10\x04\x12\x10\n\x0cPUNCTURE_6_7\x10\x05\x12\x10\n\x0cPUNCTURE_7_8\x10\x06\"\x17\n\x15\x43\x43SDSScramblingParams\"\xab\x01\n\x16\x43\x43SDSReedSolomonParams\x12^\n\x11\x62lock_length_type\x18\x01 \x01(\x0e\x32\x43.stellarstation.api.v1.radio.CCSDSReedSolomonParams.BlockLengthType\"1\n\x0f\x42lockLengthType\x12\x0e\n\nRS_223_255\x10\x00\x12\x0e\n\nRS_239_255\x10\x01\"\xc5\x03\n\x12\x43\x43SDSTransferFrame\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12`\n\x1b\x63onvolutional_coding_params\x18\x02 \x01(\x0b\x32;.stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams\x12M\n\x11scrambling_params\x18\x03 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.CCSDSScramblingParams\x12P\n\x13reed_solomon_params\x18\x04 \x01(\x0b\x32\x33.stellarstation.api.v1.radio.CCSDSReedSolomonParams\x12\x1a\n\x12\x66rame_length_bytes\x18\x05 \x01(\r\x12<\n\x0bline_coding\x18\x06 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\"\xb4\x01\n\x08\x41SMGolay\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12\x1d\n\x15\x65nable_ccsds_scramble\x18\x02 \x01(\x08\x12\x1b\n\x13\x65nable_reed_solomon\x18\x03 \x01(\x08\x12\x18\n\x10\x65nable_crc_check\x18\x04 \x01(\x08\"\xb9\x01\n\tBitstream\x12R\n\x16synchronization_params\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.radio.SynchronizationParams\x12\x1a\n\x12\x66rame_length_bytes\x18\x02 \x01(\r\x12<\n\x0bline_coding\x18\x03 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\"J\n\x15SynchronizationParams\x12\x1c\n\x14synchronization_word\x18\x01 \x01(\x0c\x12\x13\n\x0blength_bits\x18\x02 \x01(\r\"{\n\x04\x41X25\x12\r\n\x05g3ruh\x18\x01 \x01(\x08\x12\x1c\n\x14\x64\x65stination_callsign\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65stination_ssid\x18\x03 \x01(\r\x12\x17\n\x0fsource_callsign\x18\x04 \x01(\t\x12\x13\n\x0bsource_ssid\x18\x05 \x01(\r\"P\n\x19\x43onvolutionalCodingParams\x12\t\n\x01k\x18\x01 \x01(\r\x12\x14\n\x0cinverse_rate\x18\x02 \x01(\r\x12\x12\n\npolynomial\x18\x03 \x03(\x0c\"\xac\x01\n\x10ScramblingParams\x12@\n\x04type\x18\x01 \x01(\x0e\x32\x32.stellarstation.api.v1.radio.ScramblingParams.Type\x12\x10\n\x08num_bits\x18\x02 \x01(\r\x12\x0c\n\x04mask\x18\x03 \x01(\x0c\x12\x0c\n\x04seed\x18\x04 \x01(\x0c\"(\n\x04Type\x12\x0c\n\x08\x41\x44\x44ITIVE\x10\x00\x12\x12\n\x0eMULTIPLICATIVE\x10\x01*\x87\x02\n\nModulation\x12\x0c\n\x08\x44ISABLED\x10\x00\x12\x07\n\x03\x46SK\x10\x01\x12\x08\n\x04\x41\x46SK\x10\x02\x12\x08\n\x04\x42PSK\x10\x03\x12\x08\n\x04MFSK\x10\x04\x12\x08\n\x04QPSK\x10\x05\x12\x08\n\x04PSK8\x10\x06\x12\t\n\x05PSK16\x10\x07\x12\t\n\x05PSK32\x10\x08\x12\t\n\x05PSK64\x10\t\x12\n\n\x06PSK128\x10\n\x12\n\n\x06PSK256\x10\x0b\x12\t\n\x05OQPSK\x10\x0c\x12\x08\n\x04QAM8\x10\r\x12\t\n\x05QAM16\x10\x0e\x12\t\n\x05QAM32\x10\x0f\x12\t\n\x05QAM64\x10\x10\x12\n\n\x06QAM128\x10\x11\x12\n\n\x06QAM256\x10\x12\x12\x07\n\x03MSK\x10\x13\x12\x08\n\x04GMSK\x10\x14\x12\x06\n\x02\x41M\x10\x15\x12\x06\n\x02\x46M\x10\x16\x12\x06\n\x02PM\x10\x17*S\n\nLineCoding\x12\t\n\x05NRZ_L\x10\x00\x12\t\n\x05NRZ_M\x10\x01\x12\t\n\x05NRZ_S\x10\x02\x12\x06\n\x02RZ\x10\x03\x12\x08\n\x04\x42P_L\x10\x04\x12\x08\n\x04\x42P_M\x10\x05\x12\x08\n\x04\x42P_S\x10\x06\x42i\n\x1f\x63om.stellarstation.api.v1.radioB\nRadioProtoP\x01Z8github.com/infostellarinc/go-stellarstation/api/v1/radiob\x06proto3')
)

_MODULATION = _descriptor.EnumDescriptor(
  name='Modulation',
  full_name='stellarstation.api.v1.radio.Modulation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DISABLED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FSK', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AFSK', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BPSK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MFSK', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QPSK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK8', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK16', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK32', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK64', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK128', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSK256', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OQPSK', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM8', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM16', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM32', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM64', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM128', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QAM256', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MSK', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GMSK', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AM', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FM', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PM', index=23, number=23,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2493,
  serialized_end=2756,
)
_sym_db.RegisterEnumDescriptor(_MODULATION)

Modulation = enum_type_wrapper.EnumTypeWrapper(_MODULATION)
_LINECODING = _descriptor.EnumDescriptor(
  name='LineCoding',
  full_name='stellarstation.api.v1.radio.LineCoding',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NRZ_L', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NRZ_M', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NRZ_S', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RZ', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_L', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_M', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP_S', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2758,
  serialized_end=2841,
)
_sym_db.RegisterEnumDescriptor(_LINECODING)

LineCoding = enum_type_wrapper.EnumTypeWrapper(_LINECODING)
DISABLED = 0
FSK = 1
AFSK = 2
BPSK = 3
MFSK = 4
QPSK = 5
PSK8 = 6
PSK16 = 7
PSK32 = 8
PSK64 = 9
PSK128 = 10
PSK256 = 11
OQPSK = 12
QAM8 = 13
QAM16 = 14
QAM32 = 15
QAM64 = 16
QAM128 = 17
QAM256 = 18
MSK = 19
GMSK = 20
AM = 21
FM = 22
PM = 23
NRZ_L = 0
NRZ_M = 1
NRZ_S = 2
RZ = 3
BP_L = 4
BP_M = 5
BP_S = 6


_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION = _descriptor.EnumDescriptor(
  name='PolynomialInversion',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.PolynomialInversion',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='G1_G2', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G1_G2_INVERTED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G2_INVERTED_G1', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='G2_G1', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=791,
  serialized_end=874,
)
_sym_db.RegisterEnumDescriptor(_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION)

_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING = _descriptor.EnumDescriptor(
  name='Puncturing',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.Puncturing',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_2_3', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_3_4', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_4_5', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_5_6', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_6_7', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUNCTURE_7_8', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=877,
  serialized_end=1006,
)
_sym_db.RegisterEnumDescriptor(_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING)

_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE = _descriptor.EnumDescriptor(
  name='BlockLengthType',
  full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams.BlockLengthType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RS_223_255', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RS_239_255', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1156,
  serialized_end=1205,
)
_sym_db.RegisterEnumDescriptor(_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE)

_SCRAMBLINGPARAMS_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='stellarstation.api.v1.radio.ScramblingParams.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ADDITIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLICATIVE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2450,
  serialized_end=2490,
)
_sym_db.RegisterEnumDescriptor(_SCRAMBLINGPARAMS_TYPE)


_RADIODEVICECONFIGURATION = _descriptor.Descriptor(
  name='RadioDeviceConfiguration',
  full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.modulation', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.bitrate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='stellarstation.api.v1.radio.RadioDeviceConfiguration.protocol', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=276,
)


_COMMUNICATIONPROTOCOL = _descriptor.Descriptor(
  name='CommunicationProtocol',
  full_name='stellarstation.api.v1.radio.CommunicationProtocol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ax25', full_name='stellarstation.api.v1.radio.CommunicationProtocol.ax25', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ccsds', full_name='stellarstation.api.v1.radio.CommunicationProtocol.ccsds', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bitstream', full_name='stellarstation.api.v1.radio.CommunicationProtocol.bitstream', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asm_golay', full_name='stellarstation.api.v1.radio.CommunicationProtocol.asm_golay', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Framing', full_name='stellarstation.api.v1.radio.CommunicationProtocol.Framing',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=279,
  serialized_end=551,
)


_CCSDSCONVOLUTIONALCODINGPARAMS = _descriptor.Descriptor(
  name='CCSDSConvolutionalCodingParams',
  full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='polynomial_inversion', full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.polynomial_inversion', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='puncturing', full_name='stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams.puncturing', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION,
    _CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=554,
  serialized_end=1006,
)


_CCSDSSCRAMBLINGPARAMS = _descriptor.Descriptor(
  name='CCSDSScramblingParams',
  full_name='stellarstation.api.v1.radio.CCSDSScramblingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1008,
  serialized_end=1031,
)


_CCSDSREEDSOLOMONPARAMS = _descriptor.Descriptor(
  name='CCSDSReedSolomonParams',
  full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_length_type', full_name='stellarstation.api.v1.radio.CCSDSReedSolomonParams.block_length_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1034,
  serialized_end=1205,
)


_CCSDSTRANSFERFRAME = _descriptor.Descriptor(
  name='CCSDSTransferFrame',
  full_name='stellarstation.api.v1.radio.CCSDSTransferFrame',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.convolutional_coding_params', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scrambling_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.scrambling_params', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reed_solomon_params', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.reed_solomon_params', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_length_bytes', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.frame_length_bytes', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.radio.CCSDSTransferFrame.line_coding', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1661,
)


_ASMGOLAY = _descriptor.Descriptor(
  name='ASMGolay',
  full_name='stellarstation.api.v1.radio.ASMGolay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.ASMGolay.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_ccsds_scramble', full_name='stellarstation.api.v1.radio.ASMGolay.enable_ccsds_scramble', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_reed_solomon', full_name='stellarstation.api.v1.radio.ASMGolay.enable_reed_solomon', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_crc_check', full_name='stellarstation.api.v1.radio.ASMGolay.enable_crc_check', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1844,
)


_BITSTREAM = _descriptor.Descriptor(
  name='Bitstream',
  full_name='stellarstation.api.v1.radio.Bitstream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_params', full_name='stellarstation.api.v1.radio.Bitstream.synchronization_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_length_bytes', full_name='stellarstation.api.v1.radio.Bitstream.frame_length_bytes', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.radio.Bitstream.line_coding', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1847,
  serialized_end=2032,
)


_SYNCHRONIZATIONPARAMS = _descriptor.Descriptor(
  name='SynchronizationParams',
  full_name='stellarstation.api.v1.radio.SynchronizationParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='synchronization_word', full_name='stellarstation.api.v1.radio.SynchronizationParams.synchronization_word', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length_bits', full_name='stellarstation.api.v1.radio.SynchronizationParams.length_bits', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2034,
  serialized_end=2108,
)


_AX25 = _descriptor.Descriptor(
  name='AX25',
  full_name='stellarstation.api.v1.radio.AX25',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='g3ruh', full_name='stellarstation.api.v1.radio.AX25.g3ruh', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_callsign', full_name='stellarstation.api.v1.radio.AX25.destination_callsign', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_ssid', full_name='stellarstation.api.v1.radio.AX25.destination_ssid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_callsign', full_name='stellarstation.api.v1.radio.AX25.source_callsign', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_ssid', full_name='stellarstation.api.v1.radio.AX25.source_ssid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2110,
  serialized_end=2233,
)


_CONVOLUTIONALCODINGPARAMS = _descriptor.Descriptor(
  name='ConvolutionalCodingParams',
  full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='k', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.k', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_rate', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.inverse_rate', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='polynomial', full_name='stellarstation.api.v1.radio.ConvolutionalCodingParams.polynomial', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2235,
  serialized_end=2315,
)


_SCRAMBLINGPARAMS = _descriptor.Descriptor(
  name='ScramblingParams',
  full_name='stellarstation.api.v1.radio.ScramblingParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='stellarstation.api.v1.radio.ScramblingParams.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num_bits', full_name='stellarstation.api.v1.radio.ScramblingParams.num_bits', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='stellarstation.api.v1.radio.ScramblingParams.mask', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seed', full_name='stellarstation.api.v1.radio.ScramblingParams.seed', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SCRAMBLINGPARAMS_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2318,
  serialized_end=2490,
)

_RADIODEVICECONFIGURATION.fields_by_name['modulation'].enum_type = _MODULATION
_RADIODEVICECONFIGURATION.fields_by_name['protocol'].message_type = _COMMUNICATIONPROTOCOL
_COMMUNICATIONPROTOCOL.fields_by_name['ax25'].message_type = _AX25
_COMMUNICATIONPROTOCOL.fields_by_name['ccsds'].message_type = _CCSDSTRANSFERFRAME
_COMMUNICATIONPROTOCOL.fields_by_name['bitstream'].message_type = _BITSTREAM
_COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'].message_type = _ASMGOLAY
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['ax25'])
_COMMUNICATIONPROTOCOL.fields_by_name['ax25'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['ccsds'])
_COMMUNICATIONPROTOCOL.fields_by_name['ccsds'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['bitstream'])
_COMMUNICATIONPROTOCOL.fields_by_name['bitstream'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_COMMUNICATIONPROTOCOL.oneofs_by_name['Framing'].fields.append(
  _COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'])
_COMMUNICATIONPROTOCOL.fields_by_name['asm_golay'].containing_oneof = _COMMUNICATIONPROTOCOL.oneofs_by_name['Framing']
_CCSDSCONVOLUTIONALCODINGPARAMS.fields_by_name['polynomial_inversion'].enum_type = _CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION
_CCSDSCONVOLUTIONALCODINGPARAMS.fields_by_name['puncturing'].enum_type = _CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING
_CCSDSCONVOLUTIONALCODINGPARAMS_POLYNOMIALINVERSION.containing_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSCONVOLUTIONALCODINGPARAMS_PUNCTURING.containing_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSREEDSOLOMONPARAMS.fields_by_name['block_length_type'].enum_type = _CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE
_CCSDSREEDSOLOMONPARAMS_BLOCKLENGTHTYPE.containing_type = _CCSDSREEDSOLOMONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['convolutional_coding_params'].message_type = _CCSDSCONVOLUTIONALCODINGPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['scrambling_params'].message_type = _CCSDSSCRAMBLINGPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['reed_solomon_params'].message_type = _CCSDSREEDSOLOMONPARAMS
_CCSDSTRANSFERFRAME.fields_by_name['line_coding'].enum_type = _LINECODING
_ASMGOLAY.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_BITSTREAM.fields_by_name['synchronization_params'].message_type = _SYNCHRONIZATIONPARAMS
_BITSTREAM.fields_by_name['line_coding'].enum_type = _LINECODING
_SCRAMBLINGPARAMS.fields_by_name['type'].enum_type = _SCRAMBLINGPARAMS_TYPE
_SCRAMBLINGPARAMS_TYPE.containing_type = _SCRAMBLINGPARAMS
DESCRIPTOR.message_types_by_name['RadioDeviceConfiguration'] = _RADIODEVICECONFIGURATION
DESCRIPTOR.message_types_by_name['CommunicationProtocol'] = _COMMUNICATIONPROTOCOL
DESCRIPTOR.message_types_by_name['CCSDSConvolutionalCodingParams'] = _CCSDSCONVOLUTIONALCODINGPARAMS
DESCRIPTOR.message_types_by_name['CCSDSScramblingParams'] = _CCSDSSCRAMBLINGPARAMS
DESCRIPTOR.message_types_by_name['CCSDSReedSolomonParams'] = _CCSDSREEDSOLOMONPARAMS
DESCRIPTOR.message_types_by_name['CCSDSTransferFrame'] = _CCSDSTRANSFERFRAME
DESCRIPTOR.message_types_by_name['ASMGolay'] = _ASMGOLAY
DESCRIPTOR.message_types_by_name['Bitstream'] = _BITSTREAM
DESCRIPTOR.message_types_by_name['SynchronizationParams'] = _SYNCHRONIZATIONPARAMS
DESCRIPTOR.message_types_by_name['AX25'] = _AX25
DESCRIPTOR.message_types_by_name['ConvolutionalCodingParams'] = _CONVOLUTIONALCODINGPARAMS
DESCRIPTOR.message_types_by_name['ScramblingParams'] = _SCRAMBLINGPARAMS
DESCRIPTOR.enum_types_by_name['Modulation'] = _MODULATION
DESCRIPTOR.enum_types_by_name['LineCoding'] = _LINECODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadioDeviceConfiguration = _reflection.GeneratedProtocolMessageType('RadioDeviceConfiguration', (_message.Message,), dict(
  DESCRIPTOR = _RADIODEVICECONFIGURATION,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """A radio device for RF communication. Usually, a satellite will have one
  or more radio devices for communicating with the ground and a ground
  station will have one or more radio devices for communicating with the
  satellite. Such devices may not actually correspond to actual hardware
  devices, i.e., in the case of Software Defined Radio (SDR).
  
  
  Attributes:
      center_frequency_hz:
          The center frequency of the device, in Hz.
      modulation:
          The type of modulation used by this radio device.
      bitrate:
          The bitrate used during modulation.
      protocol:
          The protocol used by this device when doing RF communication.
          If unset, the device is only demodulating / modulating without
          applying any higher-level communication protocol.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.RadioDeviceConfiguration)
  ))
_sym_db.RegisterMessage(RadioDeviceConfiguration)

CommunicationProtocol = _reflection.GeneratedProtocolMessageType('CommunicationProtocol', (_message.Message,), dict(
  DESCRIPTOR = _COMMUNICATIONPROTOCOL,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """A communication protocol used with a radio device. These must contain
  all the parameters needed to configure the device for use either in
  transmission or reception.
  
  
  Attributes:
      ax25:
          AX.25 protocol settings.
      ccsds:
          CCSDS transfer frame settings.
      bitstream:
          Bitstream framing settings.
      asm_golay:
          AX 100 ASM + Golay mode.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CommunicationProtocol)
  ))
_sym_db.RegisterMessage(CommunicationProtocol)

CCSDSConvolutionalCodingParams = _reflection.GeneratedProtocolMessageType('CCSDSConvolutionalCodingParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSCONVOLUTIONALCODINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific convolutional coding parameters. Code rate (r): 1/2
  Constraint length (K): 7 Connection vectors: G1 = 1111001 G2 = 1011011
  
  
  Attributes:
      puncturing:
          Optional puncturing for convolutional code.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSConvolutionalCodingParams)
  ))
_sym_db.RegisterMessage(CCSDSConvolutionalCodingParams)

CCSDSScramblingParams = _reflection.GeneratedProtocolMessageType('CCSDSScramblingParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSSCRAMBLINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific scrambling parameters. Additive scrambler with
  pseudo-random sequence generated by the polynomial: h(x) = x^8 + x^7 +
  x^5 + x^3 + 1
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSScramblingParams)
  ))
_sym_db.RegisterMessage(CCSDSScramblingParams)

CCSDSReedSolomonParams = _reflection.GeneratedProtocolMessageType('CCSDSReedSolomonParams', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSREEDSOLOMONPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """CCSDS-specific Reed-Solomon parameters.
  
  
  Attributes:
      block_length_type:
          Block length type for RS code.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSReedSolomonParams)
  ))
_sym_db.RegisterMessage(CCSDSReedSolomonParams)

CCSDSTransferFrame = _reflection.GeneratedProtocolMessageType('CCSDSTransferFrame', (_message.Message,), dict(
  DESCRIPTOR = _CCSDSTRANSFERFRAME,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """https://public.ccsds.org/Pubs/131x0b3e1.pdf
  
  CCSDS transfer frames allow for a few common variations satellites use
  such as setting a custom synchronization word, inverting the
  convolutional coding polynomials, etc. The sequence of error-correcting
  codes will be applied as they are defined in the CCSDS standard.
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, synchronization
          will be enabled using the default CCSDS transfer frame
          standard synchronization word as in 9.3.5 (Page 9-3) in the
          specification.
      convolutional_coding_params:
          Convolutional coding parameters. If unset, convolutional
          coding is disabled.
      scrambling_params:
          Scrambling parameters. If unset, scrambling is disabled.
      reed_solomon_params:
          Reed-Solomon parameters. If unset, Reed-Solomon is disabled.
      frame_length_bytes:
          Frame length, in bytes.
      line_coding:
          Line coding used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.CCSDSTransferFrame)
  ))
_sym_db.RegisterMessage(CCSDSTransferFrame)

ASMGolay = _reflection.GeneratedProtocolMessageType('ASMGolay', (_message.Message,), dict(
  DESCRIPTOR = _ASMGOLAY,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """ASM+Golay mode for GOM Space AX100 radio.
  https://gomspace.com/UserFiles/Subsystems/datasheet/gs-ds-nanocom-ax100-33.pdf
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, the default
          synchronization word defined by the AX100 will be used.
      enable_ccsds_scramble:
          Whether to enable CCSDS scrambling.
      enable_reed_solomon:
          Whether to enable Reed Solomon error correction.
      enable_crc_check:
          Whether to enable CRC checking.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ASMGolay)
  ))
_sym_db.RegisterMessage(ASMGolay)

Bitstream = _reflection.GeneratedProtocolMessageType('Bitstream', (_message.Message,), dict(
  DESCRIPTOR = _BITSTREAM,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Framing for satellites that don’t conform to a particular standard.
  Usually, only a synchronization word and expected frame length can be
  set.
  
  
  Attributes:
      synchronization_params:
          Synchronization word parameters. If unset, synchronization is
          disabled.
      frame_length_bytes:
          Frame length, in bytes.
      line_coding:
          Line coding used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.Bitstream)
  ))
_sym_db.RegisterMessage(Bitstream)

SynchronizationParams = _reflection.GeneratedProtocolMessageType('SynchronizationParams', (_message.Message,), dict(
  DESCRIPTOR = _SYNCHRONIZATIONPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for frame synchronization.
  
  
  Attributes:
      synchronization_word:
          The actual bytes of the synchronization word. Least
          significant bit aligned E.g. 15-bit sync word of 0x7fff should
          be represented as 0111 1111 1111 1111 or [0x7f, 0xff]
      length_bits:
          The length in bits of the synchronization word.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.SynchronizationParams)
  ))
_sym_db.RegisterMessage(SynchronizationParams)

AX25 = _reflection.GeneratedProtocolMessageType('AX25', (_message.Message,), dict(
  DESCRIPTOR = _AX25,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """PACKET communication based on AX.25.
  https://www.sigidwiki.com/wiki/PACKET.
  
  
  Attributes:
      g3ruh:
          Whether or not G3RUH scrambling is used.
      destination_callsign:
          Destination callsign.
      destination_ssid:
          Destination SSID.
      source_callsign:
          Source callsign.
      source_ssid:
          Source SSID.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.AX25)
  ))
_sym_db.RegisterMessage(AX25)

ConvolutionalCodingParams = _reflection.GeneratedProtocolMessageType('ConvolutionalCodingParams', (_message.Message,), dict(
  DESCRIPTOR = _CONVOLUTIONALCODINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for convolutional coding applied to a bitstream.
  https://en.wikipedia.org/wiki/Convolutional_code
  
  
  Attributes:
      k:
          The constraint length, ``k``, of the code.
      inverse_rate:
          The inverse of the rate of coding, e.g., if rate is ``1 / r``,
          ``inverse_rate`` is ``r``.
      polynomial:
          The polynomials used for coding. Must have ``r`` number of
          elements, where the most significant ``k`` bits of each
          element will be used as the polynomial for that index.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ConvolutionalCodingParams)
  ))
_sym_db.RegisterMessage(ConvolutionalCodingParams)

ScramblingParams = _reflection.GeneratedProtocolMessageType('ScramblingParams', (_message.Message,), dict(
  DESCRIPTOR = _SCRAMBLINGPARAMS,
  __module__ = 'stellarstation.api.v1.radio.radio_pb2'
  ,
  __doc__ = """Parameters for scrambling applied to a bitstream.
  
  
  Attributes:
      type:
          The type of scrambling.
      num_bits:
          The length of the shift register, in bits.
      mask:
          The polynomial mask for the shift register. The most
          significant ``num_bits`` bits of ``mask`` will be used.
      seed:
          The initial contents of the shift register. The most
          significant ``num_bits`` bits of ``mask`` will be used.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.radio.ScramblingParams)
  ))
_sym_db.RegisterMessage(ScramblingParams)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/stellarstation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from stellarstation.api.v1.orbit import orbit_pb2 as stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2
from stellarstation.api.v1 import transport_pb2 as stellarstation_dot_api_dot_v1_dot_transport__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/stellarstation.proto',
  package='stellarstation.api.v1',
  syntax='proto3',
  serialized_options=_b('\n\031com.stellarstation.api.v1B\023StellarstationProtoP\001Z2github.com/infostellarinc/go-stellarstation/api/v1'),
  serialized_pb=_b('\n*stellarstation/api/v1/stellarstation.proto\x12\x15stellarstation.api.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'stellarstation/api/v1/orbit/orbit.proto\x1a%stellarstation/api/v1/transport.proto\"\x91\x02\n\x16SatelliteStreamRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12\x11\n\tstream_id\x18\x02 \x01(\t\x12\x15\n\renable_events\x18\x05 \x01(\x08\x12\x12\n\nrequest_id\x18\x06 \x01(\t\x12^\n\x1fsend_satellite_commands_request\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.SendSatelliteCommandsRequestH\x00\x12\x38\n\x10\x61\x63\x63\x65pted_framing\x18\x04 \x03(\x0e\x32\x1e.stellarstation.api.v1.FramingB\t\n\x07Request\"/\n\x1cSendSatelliteCommandsRequest\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\x0c\"\xcb\x01\n\x17SatelliteStreamResponse\x12\x11\n\tstream_id\x18\x01 \x01(\t\x12U\n\x1areceive_telemetry_response\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.ReceiveTelemetryResponseH\x00\x12:\n\x0cstream_event\x18\x03 \x01(\x0b\x32\".stellarstation.api.v1.StreamEventH\x00\x42\n\n\x08Response\"`\n\x18ReceiveTelemetryResponse\x12\x33\n\ttelemetry\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.Telemetry\x12\x0f\n\x07plan_id\x18\x02 \x01(\t\"$\n\x11\x43\x61ncelPlanRequest\x12\x0f\n\x07plan_id\x18\x01 \x01(\t\"\x14\n\x12\x43\x61ncelPlanResponse\":\n\"ListUpcomingAvailablePassesRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"P\n#ListUpcomingAvailablePassesResponse\x12)\n\x04pass\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Pass\"/\n\x12ReservePassRequest\x12\x19\n\x11reservation_token\x18\x01 \x01(\t\"@\n\x13ReservePassResponse\x12)\n\x04plan\x18\x01 \x01(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\x87\x01\n\x10ListPlansRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\taos_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\naos_before\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n\x11ListPlansResponse\x12)\n\x04plan\x18\x01 \x03(\x0b\x32\x1b.stellarstation.api.v1.Plan\"\x86\x03\n\x04Pass\x12\x19\n\x11reservation_token\x18\x01 \x01(\t\x12,\n\x08\x61os_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x04 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x05 \x01(\x01\x12#\n\x1bground_station_country_code\x18\x06 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\x07 \x01(\x01\x12\x36\n\x12max_elevation_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x1c\x64ownlink_center_frequency_hz\x18\t \x01(\x04\x12\"\n\x1auplink_center_frequency_hz\x18\n \x01(\x04\"\x99\x01\n\x11TelemetryMetadata\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x44\n\tdata_type\x18\x02 \x01(\x0e\x32\x31.stellarstation.api.v1.TelemetryMetadata.DataType\"1\n\x08\x44\x61taType\x12\x07\n\x03RAW\x10\x00\x12\x0f\n\x0b\x44\x45MODULATED\x10\x01\x12\x0b\n\x07\x44\x45\x43ODED\x10\x02\"\xc5\x05\n\x04Plan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0csatellite_id\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".stellarstation.api.v1.Plan.Status\x12.\n\nstart_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x61os_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08los_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1f\n\x17ground_station_latitude\x18\x06 \x01(\x01\x12 \n\x18ground_station_longitude\x18\x07 \x01(\x01\x12#\n\x1bground_station_country_code\x18\x08 \x01(\t\x12\x1d\n\x15max_elevation_degrees\x18\t \x01(\x01\x12\x36\n\x12max_elevation_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\x1c\x64ownlink_center_frequency_hz\x18\x0b \x01(\x04\x12\"\n\x1auplink_center_frequency_hz\x18\x0c \x01(\x04\x12\x44\n\x12telemetry_metadata\x18\r \x03(\x0b\x32(.stellarstation.api.v1.TelemetryMetadata\"^\n\x06Status\x12\x0c\n\x08RESERVED\x10\x00\x12\r\n\tEXECUTING\x10\x01\x12\r\n\tSUCCEEDED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0e\n\nPROCESSING\x10\x05\"T\n\rAddTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\x12-\n\x03tle\x18\x02 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle\"\x10\n\x0e\x41\x64\x64TleResponse\"%\n\rGetTleRequest\x12\x14\n\x0csatellite_id\x18\x01 \x01(\t\"?\n\x0eGetTleResponse\x12-\n\x03tle\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle2\xff\x05\n\x15StellarStationService\x12^\n\tListPlans\x12\'.stellarstation.api.v1.ListPlansRequest\x1a(.stellarstation.api.v1.ListPlansResponse\x12\x61\n\nCancelPlan\x12(.stellarstation.api.v1.CancelPlanRequest\x1a).stellarstation.api.v1.CancelPlanResponse\x12\x94\x01\n\x1bListUpcomingAvailablePasses\x12\x39.stellarstation.api.v1.ListUpcomingAvailablePassesRequest\x1a:.stellarstation.api.v1.ListUpcomingAvailablePassesResponse\x12x\n\x13OpenSatelliteStream\x12-.stellarstation.api.v1.SatelliteStreamRequest\x1a..stellarstation.api.v1.SatelliteStreamResponse(\x01\x30\x01\x12\x64\n\x0bReservePass\x12).stellarstation.api.v1.ReservePassRequest\x1a*.stellarstation.api.v1.ReservePassResponse\x12U\n\x06\x41\x64\x64Tle\x12$.stellarstation.api.v1.AddTleRequest\x1a%.stellarstation.api.v1.AddTleResponse\x12U\n\x06GetTle\x12$.stellarstation.api.v1.GetTleRequest\x1a%.stellarstation.api.v1.GetTleResponseBf\n\x19\x63om.stellarstation.api.v1B\x13StellarstationProtoP\x01Z2github.com/infostellarinc/go-stellarstation/api/v1b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_transport__pb2.DESCRIPTOR,])



_TELEMETRYMETADATA_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='stellarstation.api.v1.TelemetryMetadata.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RAW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEMODULATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECODED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1828,
  serialized_end=1877,
)
_sym_db.RegisterEnumDescriptor(_TELEMETRYMETADATA_DATATYPE)

_PLAN_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.Plan.Status',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESERVED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUCCEEDED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESSING', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2495,
  serialized_end=2589,
)
_sym_db.RegisterEnumDescriptor(_PLAN_STATUS)


_SATELLITESTREAMREQUEST = _descriptor.Descriptor(
  name='SatelliteStreamRequest',
  full_name='stellarstation.api.v1.SatelliteStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.stream_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enable_events', full_name='stellarstation.api.v1.SatelliteStreamRequest.enable_events', index=2,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_id', full_name='stellarstation.api.v1.SatelliteStreamRequest.request_id', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_satellite_commands_request', full_name='stellarstation.api.v1.SatelliteStreamRequest.send_satellite_commands_request', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted_framing', full_name='stellarstation.api.v1.SatelliteStreamRequest.accepted_framing', index=5,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Request', full_name='stellarstation.api.v1.SatelliteStreamRequest.Request',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=183,
  serialized_end=456,
)


_SENDSATELLITECOMMANDSREQUEST = _descriptor.Descriptor(
  name='SendSatelliteCommandsRequest',
  full_name='stellarstation.api.v1.SendSatelliteCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.SendSatelliteCommandsRequest.command', index=0,
      number=2, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=505,
)


_SATELLITESTREAMRESPONSE = _descriptor.Descriptor(
  name='SatelliteStreamResponse',
  full_name='stellarstation.api.v1.SatelliteStreamResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receive_telemetry_response', full_name='stellarstation.api.v1.SatelliteStreamResponse.receive_telemetry_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream_event', full_name='stellarstation.api.v1.SatelliteStreamResponse.stream_event', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Response', full_name='stellarstation.api.v1.SatelliteStreamResponse.Response',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=508,
  serialized_end=711,
)


_RECEIVETELEMETRYRESPONSE = _descriptor.Descriptor(
  name='ReceiveTelemetryResponse',
  full_name='stellarstation.api.v1.ReceiveTelemetryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='telemetry', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.telemetry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.ReceiveTelemetryResponse.plan_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=713,
  serialized_end=809,
)


_CANCELPLANREQUEST = _descriptor.Descriptor(
  name='CancelPlanRequest',
  full_name='stellarstation.api.v1.CancelPlanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan_id', full_name='stellarstation.api.v1.CancelPlanRequest.plan_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=811,
  serialized_end=847,
)


_CANCELPLANRESPONSE = _descriptor.Descriptor(
  name='CancelPlanResponse',
  full_name='stellarstation.api.v1.CancelPlanResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=869,
)


_LISTUPCOMINGAVAILABLEPASSESREQUEST = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesRequest',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=929,
)


_LISTUPCOMINGAVAILABLEPASSESRESPONSE = _descriptor.Descriptor(
  name='ListUpcomingAvailablePassesResponse',
  full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pass', full_name='stellarstation.api.v1.ListUpcomingAvailablePassesResponse.pass', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=931,
  serialized_end=1011,
)


_RESERVEPASSREQUEST = _descriptor.Descriptor(
  name='ReservePassRequest',
  full_name='stellarstation.api.v1.ReservePassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.ReservePassRequest.reservation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1013,
  serialized_end=1060,
)


_RESERVEPASSRESPONSE = _descriptor.Descriptor(
  name='ReservePassResponse',
  full_name='stellarstation.api.v1.ReservePassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ReservePassResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1126,
)


_LISTPLANSREQUEST = _descriptor.Descriptor(
  name='ListPlansRequest',
  full_name='stellarstation.api.v1.ListPlansRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.ListPlansRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_after', full_name='stellarstation.api.v1.ListPlansRequest.aos_after', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_before', full_name='stellarstation.api.v1.ListPlansRequest.aos_before', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1129,
  serialized_end=1264,
)


_LISTPLANSRESPONSE = _descriptor.Descriptor(
  name='ListPlansResponse',
  full_name='stellarstation.api.v1.ListPlansResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.ListPlansResponse.plan', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1266,
  serialized_end=1328,
)


_PASS = _descriptor.Descriptor(
  name='Pass',
  full_name='stellarstation.api.v1.Pass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='reservation_token', full_name='stellarstation.api.v1.Pass.reservation_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Pass.aos_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Pass.los_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Pass.ground_station_latitude', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Pass.ground_station_longitude', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Pass.ground_station_country_code', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Pass.max_elevation_degrees', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Pass.max_elevation_time', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_center_frequency_hz', full_name='stellarstation.api.v1.Pass.downlink_center_frequency_hz', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_center_frequency_hz', full_name='stellarstation.api.v1.Pass.uplink_center_frequency_hz', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1331,
  serialized_end=1721,
)


_TELEMETRYMETADATA = _descriptor.Descriptor(
  name='TelemetryMetadata',
  full_name='stellarstation.api.v1.TelemetryMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='stellarstation.api.v1.TelemetryMetadata.url', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='stellarstation.api.v1.TelemetryMetadata.data_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TELEMETRYMETADATA_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1877,
)


_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='stellarstation.api.v1.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='stellarstation.api.v1.Plan.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.Plan.satellite_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.Plan.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='stellarstation.api.v1.Plan.start_time', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='stellarstation.api.v1.Plan.end_time', index=4,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aos_time', full_name='stellarstation.api.v1.Plan.aos_time', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='los_time', full_name='stellarstation.api.v1.Plan.los_time', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_latitude', full_name='stellarstation.api.v1.Plan.ground_station_latitude', index=7,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_longitude', full_name='stellarstation.api.v1.Plan.ground_station_longitude', index=8,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ground_station_country_code', full_name='stellarstation.api.v1.Plan.ground_station_country_code', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_degrees', full_name='stellarstation.api.v1.Plan.max_elevation_degrees', index=10,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_elevation_time', full_name='stellarstation.api.v1.Plan.max_elevation_time', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downlink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.downlink_center_frequency_hz', index=12,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uplink_center_frequency_hz', full_name='stellarstation.api.v1.Plan.uplink_center_frequency_hz', index=13,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='telemetry_metadata', full_name='stellarstation.api.v1.Plan.telemetry_metadata', index=14,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLAN_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1880,
  serialized_end=2589,
)


_ADDTLEREQUEST = _descriptor.Descriptor(
  name='AddTleRequest',
  full_name='stellarstation.api.v1.AddTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.AddTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.AddTleRequest.tle', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=2675,
)


_ADDTLERESPONSE = _descriptor.Descriptor(
  name='AddTleResponse',
  full_name='stellarstation.api.v1.AddTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2677,
  serialized_end=2693,
)


_GETTLEREQUEST = _descriptor.Descriptor(
  name='GetTleRequest',
  full_name='stellarstation.api.v1.GetTleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='satellite_id', full_name='stellarstation.api.v1.GetTleRequest.satellite_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2695,
  serialized_end=2732,
)


_GETTLERESPONSE = _descriptor.Descriptor(
  name='GetTleResponse',
  full_name='stellarstation.api.v1.GetTleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.GetTleResponse.tle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2734,
  serialized_end=2797,
)

_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].message_type = _SENDSATELLITECOMMANDSREQUEST
_SATELLITESTREAMREQUEST.fields_by_name['accepted_framing'].enum_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._FRAMING
_SATELLITESTREAMREQUEST.oneofs_by_name['Request'].fields.append(
  _SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'])
_SATELLITESTREAMREQUEST.fields_by_name['send_satellite_commands_request'].containing_oneof = _SATELLITESTREAMREQUEST.oneofs_by_name['Request']
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].message_type = _RECEIVETELEMETRYRESPONSE
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._STREAMEVENT
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'])
_SATELLITESTREAMRESPONSE.fields_by_name['receive_telemetry_response'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_SATELLITESTREAMRESPONSE.oneofs_by_name['Response'].fields.append(
  _SATELLITESTREAMRESPONSE.fields_by_name['stream_event'])
_SATELLITESTREAMRESPONSE.fields_by_name['stream_event'].containing_oneof = _SATELLITESTREAMRESPONSE.oneofs_by_name['Response']
_RECEIVETELEMETRYRESPONSE.fields_by_name['telemetry'].message_type = stellarstation_dot_api_dot_v1_dot_transport__pb2._TELEMETRY
_LISTUPCOMINGAVAILABLEPASSESRESPONSE.fields_by_name['pass'].message_type = _PASS
_RESERVEPASSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_LISTPLANSREQUEST.fields_by_name['aos_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSREQUEST.fields_by_name['aos_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPLANSRESPONSE.fields_by_name['plan'].message_type = _PLAN
_PASS.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PASS.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TELEMETRYMETADATA.fields_by_name['data_type'].enum_type = _TELEMETRYMETADATA_DATATYPE
_TELEMETRYMETADATA_DATATYPE.containing_type = _TELEMETRYMETADATA
_PLAN.fields_by_name['status'].enum_type = _PLAN_STATUS
_PLAN.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['aos_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['los_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['max_elevation_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PLAN.fields_by_name['telemetry_metadata'].message_type = _TELEMETRYMETADATA
_PLAN_STATUS.containing_type = _PLAN
_ADDTLEREQUEST.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
_GETTLERESPONSE.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
DESCRIPTOR.message_types_by_name['SatelliteStreamRequest'] = _SATELLITESTREAMREQUEST
DESCRIPTOR.message_types_by_name['SendSatelliteCommandsRequest'] = _SENDSATELLITECOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['SatelliteStreamResponse'] = _SATELLITESTREAMRESPONSE
DESCRIPTOR.message_types_by_name['ReceiveTelemetryResponse'] = _RECEIVETELEMETRYRESPONSE
DESCRIPTOR.message_types_by_name['CancelPlanRequest'] = _CANCELPLANREQUEST
DESCRIPTOR.message_types_by_name['CancelPlanResponse'] = _CANCELPLANRESPONSE
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesRequest'] = _LISTUPCOMINGAVAILABLEPASSESREQUEST
DESCRIPTOR.message_types_by_name['ListUpcomingAvailablePassesResponse'] = _LISTUPCOMINGAVAILABLEPASSESRESPONSE
DESCRIPTOR.message_types_by_name['ReservePassRequest'] = _RESERVEPASSREQUEST
DESCRIPTOR.message_types_by_name['ReservePassResponse'] = _RESERVEPASSRESPONSE
DESCRIPTOR.message_types_by_name['ListPlansRequest'] = _LISTPLANSREQUEST
DESCRIPTOR.message_types_by_name['ListPlansResponse'] = _LISTPLANSRESPONSE
DESCRIPTOR.message_types_by_name['Pass'] = _PASS
DESCRIPTOR.message_types_by_name['TelemetryMetadata'] = _TELEMETRYMETADATA
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['AddTleRequest'] = _ADDTLEREQUEST
DESCRIPTOR.message_types_by_name['AddTleResponse'] = _ADDTLERESPONSE
DESCRIPTOR.message_types_by_name['GetTleRequest'] = _GETTLEREQUEST
DESCRIPTOR.message_types_by_name['GetTleResponse'] = _GETTLERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SatelliteStreamRequest = _reflection.GeneratedProtocolMessageType('SatelliteStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A request to send on the satellite stream. Currently only command
  sending to the satellite is supported. The request does not need to be
  filled on the first request to ``OpenSatelliteStream``.
  
  
  Attributes:
      satellite_id:
          The ID of the satellite to open a stream with. The ID of a
          satellite can be found on the StellarStation Console page for
          the satellite.
      stream_id:
          The ``SatelliteStreamResponse.stream_id`` from a previously
          opened stream to resume. If the specified stream has already
          expired or been closed, the stream is closed with a
          ``ABORTED`` error.
      enable_events:
          Whether monitoring events should be returned by the stream in
          ``SatelliteStreamResponse.stream_event``. If set in the first
          request of the stream, events of type ``StreamEvent`` will be
          returned throughout the lifetime of the stream.
      request_id:
          A unique ID identifying this request. If ``enable_events`` is
          true and this is filled, events returned in
          ``SatelliteStreamResponse.stream_event`` that correspond to
          this request will have this value copied into
          ``StreamEvent.request_id`` for correlation. The API will treat
          this as an opaque identifier which can be set to any value,
          e.g., to the same value as the request ID or command number in
          a downstream system. For simple cases, it is often simplest to
          set this to a standard UUID.
      send_satellite_commands_request:
          A request to send commands to the satellite.
      accepted_framing:
          The ``Framing`` types to accept, for satellites that have been
          configured for multiple framings (e.g., IQ + AX25). If empty,
          all framings produced by the satellite will be returned.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamRequest)
  ))
_sym_db.RegisterMessage(SatelliteStreamRequest)

SendSatelliteCommandsRequest = _reflection.GeneratedProtocolMessageType('SendSatelliteCommandsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SENDSATELLITECOMMANDSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A request to send commands to a satellite.
  
  Next ID: 3
  
  
  Attributes:
      command:
          The command frames to send to the satellite. All commands will
          be transmitted in sequence immediately, during which time
          telemetry will not be received. After all commands have been
          transmitted, telemetry receive will be immediately re-enabled.
          The maximum size of each command is 2MB. If a command larger
          than 2MB is received, the stream will be closed with a
          ``RESOURCE_EXHAUSTED`` error.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SendSatelliteCommandsRequest)
  ))
_sym_db.RegisterMessage(SendSatelliteCommandsRequest)

SatelliteStreamResponse = _reflection.GeneratedProtocolMessageType('SatelliteStreamResponse', (_message.Message,), dict(
  DESCRIPTOR = _SATELLITESTREAMRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A response on the stream. Currently the only type of response is
  telemetry received from the satellite.
  
  
  Attributes:
      stream_id:
          The ID of this stream, which can be used in a subsequent call
          to ``OpenSatelliteStream`` to resume this stream on
          interruption (e.g., if a network failure causes the connection
          to be closed mid-stream). Telemetry received on a previously
          opened stream with no current listener will be buffered for a
          maximum of 1 minute, and the stream itself will be cancelled
          and no more buffering will occur if no client resumes the
          stream with ``OpenSatelliteStream`` within 10 minutes.
      receive_telemetry_response:
          A response from a satellite containing telemetry.
      stream_event:
          An event that occurred while processing the stream. Often used
          for monitoring the stream. Never returned if
          ``SatelliteStreamRequest.enable_events`` is false in the first
          ``SatelliteStreamRequest`` of the stream.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.SatelliteStreamResponse)
  ))
_sym_db.RegisterMessage(SatelliteStreamResponse)

ReceiveTelemetryResponse = _reflection.GeneratedProtocolMessageType('ReceiveTelemetryResponse', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVETELEMETRYRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A response from a satellite containing telemetry.
  
  
  Attributes:
      telemetry:
          The telemetry received.
      plan_id:
          The ID of the plan the telemetry was received for.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReceiveTelemetryResponse)
  ))
_sym_db.RegisterMessage(ReceiveTelemetryResponse)

CancelPlanRequest = _reflection.GeneratedProtocolMessageType('CancelPlanRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELPLANREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ``CancelPlan`` method.
  
  
  Attributes:
      plan_id:
          The id of the plan to cancel, i.e., the value of ``Plan.id``.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanRequest)
  ))
_sym_db.RegisterMessage(CancelPlanRequest)

CancelPlanResponse = _reflection.GeneratedProtocolMessageType('CancelPlanResponse', (_message.Message,), dict(
  DESCRIPTOR = _CANCELPLANRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Response for the ``CancelPlan`` method.
  
  Currently no payload in the response.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.CancelPlanResponse)
  ))
_sym_db.RegisterMessage(CancelPlanResponse)

ListUpcomingAvailablePassesRequest = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTUPCOMINGAVAILABLEPASSESREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ``ListUpcomingAvailablePasses`` method.
  
  
  Attributes:
      satellite_id:
          The ID of the satellite to list passes for. The ID of a
          satellite can be found on the StellarStation Console page for
          the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesRequest)
  ))
_sym_db.RegisterMessage(ListUpcomingAvailablePassesRequest)

ListUpcomingAvailablePassesResponse = _reflection.GeneratedProtocolMessageType('ListUpcomingAvailablePassesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTUPCOMINGAVAILABLEPASSESRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Response for the ``ListUpcomingAvailablePasses`` method.
  
  
  Attributes:
      pass:
          The upcoming, schedulable passes for the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListUpcomingAvailablePassesResponse)
  ))
_sym_db.RegisterMessage(ListUpcomingAvailablePassesResponse)

ReservePassRequest = _reflection.GeneratedProtocolMessageType('ReservePassRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESERVEPASSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ``ReservePass`` method.
  
  
  Attributes:
      reservation_token:
          The token that specifies the pass, as returned in
          ``Pass.reservation_token``.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassRequest)
  ))
_sym_db.RegisterMessage(ReservePassRequest)

ReservePassResponse = _reflection.GeneratedProtocolMessageType('ReservePassResponse', (_message.Message,), dict(
  DESCRIPTOR = _RESERVEPASSRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Response for the ``ReservePass`` method.
  
  
  Attributes:
      plan:
          The reserved plan.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ReservePassResponse)
  ))
_sym_db.RegisterMessage(ReservePassResponse)

ListPlansRequest = _reflection.GeneratedProtocolMessageType('ListPlansRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ``ListPlans`` method.
  
  
  Attributes:
      satellite_id:
          The ID of the satellite to list plans for. The ID can be found
          on the StellarStation Console page for the satellite.
      aos_after:
          The start time of the range of plans to list (inclusive). Only
          plans with an Acquisition of Signal (AOS) at or after this
          time will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
      aos_before:
          The end time of the range of plans to list (exclusive). Only
          plans with an Acquisition of Signal (AOS) before this time
          will be returned. It is an error for the duration between
          ``aos_after`` and ``aos_before`` to be longer than 31 days.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansRequest)
  ))
_sym_db.RegisterMessage(ListPlansRequest)

ListPlansResponse = _reflection.GeneratedProtocolMessageType('ListPlansResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTPLANSRESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A response from the ``ListPlans`` method.
  
  
  Attributes:
      plan:
          The requested list of plans for the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.ListPlansResponse)
  ))
_sym_db.RegisterMessage(ListPlansResponse)

Pass = _reflection.GeneratedProtocolMessageType('Pass', (_message.Message,), dict(
  DESCRIPTOR = _PASS,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A pass during which a satellite can be communicated with from a given
  ground station.
  
  
  Attributes:
      reservation_token:
          A unique token for this pass that can be used for scheduling
          it.
      aos_time:
          The time of Acquisition of Signal (AOS) between the ground
          station and satellite in this pass.
      los_time:
          The time of Loss of Signal (LOS) between the ground station
          and satellite in this pass.
      ground_station_latitude:
          The latitude, in degrees, of the ground station’s location.
      ground_station_longitude:
          The longitude, in degrees, of the ground station’s location.
      ground_station_country_code:
          The ISO 3166-1 alpha-2 2-letter country code for the ground
          station’s location. See
          https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2
      max_elevation_degrees:
          The max elevation during the pass, in degrees.
      max_elevation_time:
          The time of the max elevation during the pass.
      downlink_center_frequency_hz:
          The center frequency, in Hz, for downlinking in this pass. 0
          if downlink is not available in this pass.
      uplink_center_frequency_hz:
          The center frequency, in Hz, for uplinking in this pass. 0 if
          uplink is not available in this pass.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Pass)
  ))
_sym_db.RegisterMessage(Pass)

TelemetryMetadata = _reflection.GeneratedProtocolMessageType('TelemetryMetadata', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRYMETADATA,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Metadata for telemetry downlinked during a pass.
  
  
  Attributes:
      url:
          URL of the data. This URL is valid for one hour after being
          returned.
      data_type:
          The type of data received during downlinking.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.TelemetryMetadata)
  ))
_sym_db.RegisterMessage(TelemetryMetadata)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """A plan, specifying a time range within which a satellite will be
  communicated with.
  
  Next ID: 16
  
  
  Attributes:
      id:
          The unique ID of the plan.
      satellite_id:
          The id of the satellite to be tracked in the plan.
      status:
          The status of this plan.
      start_time:
          The start of the time window reserved for the plan. This value
          does not change over time.
      end_time:
          The end of the time window reserved for the plan. This value
          does not change over time.
      aos_time:
          The time of Acquisition of Signal (AOS) between the ground
          station and satellite in this plan.  This value is never
          before ‘start_time’. It may change over time (for example, if
          updated TLE becomes available).
      los_time:
          The time of Loss of Signal (LOS) between the ground station
          and satellite in this plan.  This value is never after
          ‘end_time’. It may change over time (for example, if updated
          TLE becomes available).
      ground_station_latitude:
          The latitude, in degrees, of the ground station’s location.
      ground_station_longitude:
          The longitude, in degrees, of the ground station’s location.
      ground_station_country_code:
          The ISO 3166-1 alpha-2 2-letter country code for the ground
          station’s location. See
          https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2
      max_elevation_degrees:
          The max elevation during the plan, in degrees.
      max_elevation_time:
          The time of the max elevation during the plan.
      downlink_center_frequency_hz:
          The center frequency, in Hz, for downlinking in this plan. 0
          if downlink is not available in this plan.
      uplink_center_frequency_hz:
          The center frequency, in Hz, for uplinking in this plan. 0 if
          uplink is not available in this plan.
      telemetry_metadata:
          Metadata for telemetry received during the pass. Only
          populated when the pass has completed successfully and data
          processing is complete.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.Plan)
  ))
_sym_db.RegisterMessage(Plan)

AddTleRequest = _reflection.GeneratedProtocolMessageType('AddTleRequest', (_message.Message,), dict(
  DESCRIPTOR = _ADDTLEREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ‘AddTle’ method.
  
  
  Attributes:
      satellite_id:
          The ID of the satellite to add TLE for. The ID can be found on
          the StellarStation Console page for the satellite.
      tle:
          The TLE to be added.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleRequest)
  ))
_sym_db.RegisterMessage(AddTleRequest)

AddTleResponse = _reflection.GeneratedProtocolMessageType('AddTleResponse', (_message.Message,), dict(
  DESCRIPTOR = _ADDTLERESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Response for the ``AddTle`` method.
  
  Currently no payload in the response.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.AddTleResponse)
  ))
_sym_db.RegisterMessage(AddTleResponse)

GetTleRequest = _reflection.GeneratedProtocolMessageType('GetTleRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTLEREQUEST,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Request for the ‘GetTle’ method.
  
  
  Attributes:
      satellite_id:
          The ID of the satellite for which to fetch TLE. The ID can be
          found on the StellarStation Console page for the satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleRequest)
  ))
_sym_db.RegisterMessage(GetTleRequest)

GetTleResponse = _reflection.GeneratedProtocolMessageType('GetTleResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTLERESPONSE,
  __module__ = 'stellarstation.api.v1.stellarstation_pb2'
  ,
  __doc__ = """Response for the ‘GetTle’ method.
  
  
  Attributes:
      tle:
          The TLE for the given satellite.
  """,
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.GetTleResponse)
  ))
_sym_db.RegisterMessage(GetTleResponse)


DESCRIPTOR._options = None

_STELLARSTATIONSERVICE = _descriptor.ServiceDescriptor(
  name='StellarStationService',
  full_name='stellarstation.api.v1.StellarStationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2800,
  serialized_end=3567,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPlans',
    full_name='stellarstation.api.v1.StellarStationService.ListPlans',
    index=0,
    containing_service=None,
    input_type=_LISTPLANSREQUEST,
    output_type=_LISTPLANSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='CancelPlan',
    full_name='stellarstation.api.v1.StellarStationService.CancelPlan',
    index=1,
    containing_service=None,
    input_type=_CANCELPLANREQUEST,
    output_type=_CANCELPLANRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ListUpcomingAvailablePasses',
    full_name='stellarstation.api.v1.StellarStationService.ListUpcomingAvailablePasses',
    index=2,
    containing_service=None,
    input_type=_LISTUPCOMINGAVAILABLEPASSESREQUEST,
    output_type=_LISTUPCOMINGAVAILABLEPASSESRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OpenSatelliteStream',
    full_name='stellarstation.api.v1.StellarStationService.OpenSatelliteStream',
    index=3,
    containing_service=None,
    input_type=_SATELLITESTREAMREQUEST,
    output_type=_SATELLITESTREAMRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='ReservePass',
    full_name='stellarstation.api.v1.StellarStationService.ReservePass',
    index=4,
    containing_service=None,
    input_type=_RESERVEPASSREQUEST,
    output_type=_RESERVEPASSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AddTle',
    full_name='stellarstation.api.v1.StellarStationService.AddTle',
    index=5,
    containing_service=None,
    input_type=_ADDTLEREQUEST,
    output_type=_ADDTLERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTle',
    full_name='stellarstation.api.v1.StellarStationService.GetTle',
    index=6,
    containing_service=None,
    input_type=_GETTLEREQUEST,
    output_type=_GETTLERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STELLARSTATIONSERVICE)

DESCRIPTOR.services_by_name['StellarStationService'] = _STELLARSTATIONSERVICE

# @@protoc_insertion_point(module_scope)
